| splitV | R Documentation |
Splits data into unequal and disjoint groups of columns (i.e. vertical splits)
splitV(data, splits)
data |
a "data.table" class data frame or convertible to "data.table" class |
splits |
integer, length 1, of value <= |
The smaller the splits value, the wider the column groups. Column order from
source data is not preserved
An exhaustive listenv of disjoint column groups from original data
if (interactive()) {
# 1. Split iris data vertically
data(iris)
a = splitV(iris, splits = 3) # split data in 3 column groups
class(a) # listenv, environment
print(as.list(a)) # list
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.